InsertMany class
Insert many SQL statement builder.
Use into method to set the table to insert into.
Use add, addAll, addMap and addAllMap to set column values.
Use exec statement or Adapter to execute the statement against a
database.
- Implemented types
Constructors
- InsertMany(String name)
Properties
- asImmutable → ImmutableInsertManyStatement
-
Read-only representation of this statement.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add(
Iterable< SetColumn> row) → InsertMany -
Adds a single
rowto be inserted. -
addAll(
Iterable< Iterable< rows) → InsertManySetColumn> > -
Adds many
rowsto be inserted. -
addAllMap(
Iterable< Map< rows) → InsertManyString, dynamic> > -
Adds many
rowsto be inserted. -
addMap(
Map< String, dynamic> row) → InsertMany -
Adds a single
rowto be inserted. -
exec<
T> (Adapter adapter) → Future< void> - Executes the statement with the given adapter.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited